import { Toaster } from "@/components/ui/toaster";
import { Toaster as Sonner } from "@/components/ui/sonner";
import { TooltipProvider } from "@/components/ui/tooltip";
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import { BrowserRouter, Routes, Route, Navigate } from "react-router-dom";
import { ThemeProvider } from "next-themes";
import { HelmetProvider } from 'react-helmet-async';
import OnboardingWrapper from "@/components/layout/OnboardingWrapper";
import Index from "./pages/Index";
import BoxDetail from "./pages/BoxDetail";
import SearchPage from "./pages/SearchPage";
import AuthPage from "./pages/AuthPage";
import InviteAuthPage from "./pages/InviteAuthPage";
import ProfilePage from "./pages/ProfilePage";
import HistoryPage from "./pages/HistoryPage";
import NotFound from "./pages/NotFound";
import AcceptInvitation from "./pages/AcceptInvitePage";
import LandingPage from "./pages/LandingPage";
import ResetPasswordPage from "./pages/ResetPasswordPage";
import ArticlesPage from "./pages/ArticlesPage";
import ArticleDetail from "./pages/ArticleDetail";
import PrivacyPolicy from "./pages/PrivacyPolicy";
import TermsOfService from "./pages/TermsOfService";
import ChecklistPage from "./pages/ChecklistPage";
import AdminPage from "./pages/AdminPage";
import AuthCallback from "./pages/auth-callback";
import "./styles/compact-mode.css";
import { useEffect } from "react";
import { supabase } from '@/integrations/supabase/client';

// Initialize compact mode from localStorage
const initCompactMode = () => {
  const savedCompactMode = localStorage.getItem('compact-mode');
  if (savedCompactMode === null) {
    // If not set yet, default to true
    localStorage.setItem('compact-mode', 'true');
    document.documentElement.setAttribute('data-compact-mode', 'true');
    console.log('App init: Compact mode enabled (default)');
  } else if (savedCompactMode === 'true') {
    document.documentElement.setAttribute('data-compact-mode', 'true');
    console.log('App init: Compact mode enabled from localStorage');
  } else {
    document.documentElement.removeAttribute('data-compact-mode');
    console.log('App init: Compact mode disabled');
  }
};

// Initialize theme preference if not already set
const initDarkMode = () => {
  // Check if theme is stored in localStorage
  const storedTheme = localStorage.getItem('theme');
  
  // If not set, initialize to dark
  if (!storedTheme) {
    localStorage.setItem('theme', 'dark');
  }
};

// Initialize view mode preference if not already set
const initViewMode = () => {
  // Check if view mode is stored in sessionStorage
  const storedViewMode = sessionStorage.getItem('hoardo_view_mode');
  
  // If not set, initialize to boxes
  if (!storedViewMode) {
    sessionStorage.setItem('hoardo_view_mode', 'boxes');
    console.log('App init: View mode set to boxes (default)');
  }
};

const queryClient = new QueryClient();

const App = () => {
  // Initialize compact mode and theme preference on app mount
  useEffect(() => {
    initCompactMode();
    initDarkMode();
    initViewMode();
  }, []);
  
  useEffect(() => {
    // Log application initialization
    const logAppStart = async () => {
      try {
        const { data: { session }, error } = await supabase.auth.getSession();
        
        if (session) {
          console.log('App initialized with authenticated user:', session.user.id);
          
          // Skip Edge Function connectivity check in local development
          const isLocalhost = window.location.hostname === 'localhost' || 
                              window.location.hostname === '127.0.0.1';
          
          // Only try to connect to edge functions in production environment
          if (!isLocalhost) {
            // Log to Supabase's Edge Function logs (for monitoring purposes)
            const supabaseUrl = import.meta.env.VITE_SUPABASE_URL || "";
            try {
              // Use a more robust way to check Edge Function availability without generating errors
              const testResponse = await fetch(`${supabaseUrl}/functions/v1/delete-user`, {
                method: 'OPTIONS',
                headers: {
                  'Content-Type': 'application/json',
                }
              });
              
              if (testResponse.ok) {
                console.log('Edge Function connectivity check successful');
              } else {
                console.warn('Edge Function might not be available:', testResponse.status);
              }
            } catch (e) {
              console.warn('Edge Function connectivity check failed - might be using a local environment');
            }
          } else {
            console.log('Local development environment detected - skipping Edge Function connectivity check');
          }
        } else {
          console.log('App initialized without authenticated user');
        }
      } catch (error) {
        console.error('Error checking session during initialization:', error);
      }
    };
    
    logAppStart();
  }, []);
  
  return (
    <HelmetProvider>
      <QueryClientProvider client={queryClient}>
        <ThemeProvider attribute="class" defaultTheme="dark">
          <TooltipProvider>
            <Toaster />
            <Sonner />
            <BrowserRouter>
              <OnboardingWrapper>
                <Routes>
                  {/* Marketing Landing Page */}
                  <Route path="/" element={<LandingPage />} />
                  
                  {/* Marketing Pages */}
                  <Route path="/articles" element={<ArticlesPage />} />
                  <Route path="/articles/:slug" element={<ArticleDetail />} />
                  <Route path="/privacy-policy" element={<PrivacyPolicy />} />
                  <Route path="/terms-of-service" element={<TermsOfService />} />
                  
                  {/* Application Routes */}
                  <Route path="/app" element={<Index />} />
                  <Route path="/box/:id" element={<BoxDetail />} />
                  <Route path="/search" element={<SearchPage />} />
                  <Route path="/auth" element={<AuthPage />} />
                  <Route path="/invite" element={<InviteAuthPage />} />
                  <Route path="/settings" element={<ProfilePage />} />
                  <Route path="/history" element={<HistoryPage />} />
                  <Route path="/checklist" element={<ChecklistPage />} />
                  <Route path="/accept-invitation" element={<AcceptInvitation />} />
                  <Route path="/reset-password" element={<ResetPasswordPage />} />
                  <Route path="/auth-callback" element={<AuthCallback />} />
                  
                  {/* Admin Routes */}
                  <Route path="/admin" element={<AdminPage />} />
                  
                  {/* Legacy route redirects */}
                  <Route path="/index" element={<Navigate to="/app" replace />} />
                  <Route path="/profile" element={<Navigate to="/settings" replace />} />
                  
                  {/* 404 Not Found */}
                  <Route path="*" element={<NotFound />} />
                </Routes>
              </OnboardingWrapper>
            </BrowserRouter>
          </TooltipProvider>
        </ThemeProvider>
      </QueryClientProvider>
    </HelmetProvider>
  );
};

export default App;
